@@ -4,12 +4,15 @@ library("lessR")
 ## ----read-------------------------------------------------------------------------------------------------------------
 d <- Read("Employee")
 
-## ---------------------------------------------------------------------------------------------------------------------
+## ----fig.width=4.5, fig.height=4.5------------------------------------------------------------------------------------
 reg_brief(Salary ~ Years + Pre)
 
 ## ---------------------------------------------------------------------------------------------------------------------
 reg(Salary ~ Years + Pre)
 
+## ---------------------------------------------------------------------------------------------------------------------
+reg_brief(Salary ~ Years + Pre, rescale="z")
+
 ## ---------------------------------------------------------------------------------------------------------------------
 reg(Salary ~ Years, kfold=3)
 
